@@ -6,6 +6,8 @@
 
 #include "dolphinviewcontainer.h"
 
+#include "admin/bar.h"
+#include "admin/workerintegration.h"
 #include "dolphin_compactmodesettings.h"
 #include "dolphin_contentdisplaysettings.h"
 #include "dolphin_detailsmodesettings.h"
@@ -20,9 +22,6 @@
 #include "statusbar/dolphinstatusbar.h"
 
 #include <KActionCollection>
-#if HAVE_PLASMA_ACTIVITIES
-#include <PlasmaActivities/ResourceInstance>
-#endif
 #include <KApplicationTrader>
 #include <KFileItemActions>
 #include <KFilePlacesModel>
@@ -46,12 +45,13 @@
 // An overview of the widgets contained by this ViewContainer
 struct LayoutStructure {
     int searchBox = 0;
-    int messageWidget = 1;
-    int selectionModeTopBar = 2;
-    int view = 3;
-    int selectionModeBottomBar = 4;
-    int filterBar = 5;
-    int statusBar = 6;
+    int adminBar = 1;
+    int messageWidget = 2;
+    int selectionModeTopBar = 3;
+    int view = 4;
+    int selectionModeBottomBar = 5;
+    int filterBar = 6;
+    int statusBar = 7;
 };
 constexpr LayoutStructure positionFor;
 
@@ -62,6 +62,8 @@ DolphinViewContainer::DolphinViewContainer(const QUrl &url, QWidget *parent)
     , m_urlNavigatorConnected{nullptr}
     , m_searchBox(nullptr)
     , m_searchModeEnabled(false)
+    , m_adminBar{nullptr}
+    , m_authorizeToEnterFolderAction{nullptr}
     , m_messageWidget(nullptr)
     , m_selectionModeTopBar{nullptr}
     , m_view(nullptr)
@@ -103,10 +105,10 @@ DolphinViewContainer::DolphinViewContainer(const QUrl &url, QWidget *parent)
     m_messageWidget->setPosition(KMessageWidget::Header);
     m_messageWidget->hide();
 
-#ifndef Q_OS_WIN
+#if !defined(Q_OS_WIN) && !defined(Q_OS_HAIKU)
     if (getuid() == 0) {
         // We must be logged in as the root user; show a big scary warning
-        showMessage(i18n("Running Dolphin as root can be dangerous. Please be careful."), Warning);
+        showMessage(i18n("Running Dolphin as root can be dangerous. Please be careful."), KMessageWidget::Warning);
     }
 #endif
 
@@ -138,10 +140,8 @@ DolphinViewContainer::DolphinViewContainer(const QUrl &url, QWidget *parent)
     connect(m_view, &DolphinView::directoryLoadingCompleted, this, &DolphinViewContainer::slotDirectoryLoadingCompleted);
     connect(m_view, &DolphinView::directoryLoadingCanceled, this, &DolphinViewContainer::slotDirectoryLoadingCanceled);
     connect(m_view, &DolphinView::itemCountChanged, this, &DolphinViewContainer::delayedStatusBarUpdate);
-    connect(m_view, &DolphinView::directoryLoadingProgress, this, &DolphinViewContainer::updateDirectoryLoadingProgress);
-    connect(m_view, &DolphinView::directorySortingProgress, this, &DolphinViewContainer::updateDirectorySortingProgress);
     connect(m_view, &DolphinView::selectionChanged, this, &DolphinViewContainer::delayedStatusBarUpdate);
-    connect(m_view, &DolphinView::errorMessage, this, &DolphinViewContainer::showErrorMessage);
+    connect(m_view, &DolphinView::errorMessage, this, &DolphinViewContainer::slotErrorMessageFromView);
     connect(m_view, &DolphinView::urlIsFileError, this, &DolphinViewContainer::slotUrlIsFileError);
     connect(m_view, &DolphinView::activated, this, &DolphinViewContainer::activate);
     connect(m_view, &DolphinView::hiddenFilesShownChanged, this, &DolphinViewContainer::slotHiddenFilesShownChanged);
@@ -158,8 +158,17 @@ DolphinViewContainer::DolphinViewContainer(const QUrl &url, QWidget *parent)
     connect(m_view, &DolphinView::operationCompletedMessage, m_statusBar, &DolphinStatusBar::setText);
     connect(m_view, &DolphinView::statusBarTextChanged, m_statusBar, &DolphinStatusBar::setDefaultText);
     connect(m_view, &DolphinView::statusBarTextChanged, m_statusBar, &DolphinStatusBar::resetToDefaultText);
+    connect(m_view, &DolphinView::directoryLoadingProgress, m_statusBar, [this](int percent) {
+        m_statusBar->showProgress(i18nc("@info:progress", "Loading folder…"), percent);
+    });
+    connect(m_view, &DolphinView::directorySortingProgress, m_statusBar, [this](int percent) {
+        m_statusBar->showProgress(i18nc("@info:progress", "Sorting…"), percent);
+    });
     connect(m_statusBar, &DolphinStatusBar::stopPressed, this, &DolphinViewContainer::stopDirectoryLoading);
     connect(m_statusBar, &DolphinStatusBar::zoomLevelChanged, this, &DolphinViewContainer::slotStatusBarZoomLevelChanged);
+    connect(m_statusBar, &DolphinStatusBar::showMessage, this, [this](const QString &message, KMessageWidget::MessageType messageType) {
+        showMessage(message, messageType);
+    });
 
     m_statusBarTimer = new QTimer(this);
     m_statusBarTimer->setSingleShot(true);
@@ -297,6 +306,8 @@ void DolphinViewContainer::connectUrlNavigator(DolphinUrlNavigator *urlNavigator
     connect(m_view, &DolphinView::urlChanged, urlNavigator, &DolphinUrlNavigator::setLocationUrl);
     connect(urlNavigator, &DolphinUrlNavigator::activated, this, &DolphinViewContainer::activate);
 
+    urlNavigator->setReadOnlyBadgeVisible(rootItem().isLocalFile() && !rootItem().isWritable());
+
     m_urlNavigatorConnected = urlNavigator;
 }
 
@@ -355,9 +366,7 @@ void DolphinViewContainer::setSelectionModeEnabled(bool enabled, KActionCollecti
         connect(m_view, &DolphinView::selectionChanged, this, [this](const KFileItemList &selection) {
             m_selectionModeBottomBar->slotSelectionChanged(selection, m_view->url());
         });
-        connect(m_selectionModeBottomBar, &SelectionMode::BottomBar::error, this, [this](const QString &errorMessage) {
-            showErrorMessage(errorMessage);
-        });
+        connect(m_selectionModeBottomBar, &SelectionMode::BottomBar::error, this, &DolphinViewContainer::showErrorMessage);
         connect(m_selectionModeBottomBar, &SelectionMode::BottomBar::selectionModeLeavingRequested, this, [this]() {
             setSelectionModeEnabled(false);
         });
@@ -397,31 +406,25 @@ void DolphinViewContainer::slotSplitTabDisabled()
     }
 }
 
-void DolphinViewContainer::showMessage(const QString &msg, MessageType type)
+void DolphinViewContainer::showMessage(const QString &message, KMessageWidget::MessageType messageType, std::initializer_list<QAction *> buttonActions)
 {
-    if (msg.isEmpty()) {
+    if (message.isEmpty()) {
         return;
     }
 
-    m_messageWidget->setText(msg);
+    m_messageWidget->setText(message);
 
     // TODO: wrap at arbitrary character positions once QLabel can do this
     // https://bugreports.qt.io/browse/QTBUG-1276
     m_messageWidget->setWordWrap(true);
+    m_messageWidget->setMessageType(messageType);
 
-    switch (type) {
-    case Information:
-        m_messageWidget->setMessageType(KMessageWidget::Information);
-        break;
-    case Warning:
-        m_messageWidget->setMessageType(KMessageWidget::Warning);
-        break;
-    case Error:
-        m_messageWidget->setMessageType(KMessageWidget::Error);
-        break;
-    default:
-        Q_ASSERT(false);
-        break;
+    const QList<QAction *> previousMessageWidgetActions = m_messageWidget->actions();
+    for (auto action : previousMessageWidgetActions) {
+        m_messageWidget->removeAction(action);
+    }
+    for (QAction *action : buttonActions) {
+        m_messageWidget->addAction(action);
     }
 
     m_messageWidget->setWordWrap(false);
@@ -575,10 +578,6 @@ void DolphinViewContainer::setUrl(const QUrl &newUrl)
     if (newUrl != m_urlNavigator->locationUrl()) {
         m_urlNavigator->setLocationUrl(newUrl);
     }
-
-#if HAVE_PLASMA_ACTIVITIES
-    KActivities::ResourceInstance::notifyAccessed(newUrl);
-#endif
 }
 
 void DolphinViewContainer::setFilterBarVisible(bool visible)
@@ -615,45 +614,28 @@ void DolphinViewContainer::updateStatusBar()
     m_view->requestStatusBarText();
 }
 
-void DolphinViewContainer::updateDirectoryLoadingProgress(int percent)
-{
-    if (m_statusBar->progressText().isEmpty()) {
-        m_statusBar->setProgressText(i18nc("@info:progress", "Loading folder…"));
-    }
-    m_statusBar->setProgress(percent);
-}
-
-void DolphinViewContainer::updateDirectorySortingProgress(int percent)
-{
-    if (m_statusBar->progressText().isEmpty()) {
-        m_statusBar->setProgressText(i18nc("@info:progress", "Sorting…"));
-    }
-    m_statusBar->setProgress(percent);
-}
-
 void DolphinViewContainer::slotDirectoryLoadingStarted()
 {
     if (isSearchUrl(url())) {
         // Search KIO-slaves usually don't provide any progress information. Give
         // a hint to the user that a searching is done:
         updateStatusBar();
-        m_statusBar->setProgressText(i18nc("@info", "Searching…"));
-        m_statusBar->setProgress(-1);
+        m_statusBar->showProgress(i18nc("@info", "Searching…"), -1);
     } else {
         // Trigger an undetermined progress indication. The progress
         // information in percent will be triggered by the percent() signal
         // of the directory lister later.
-        m_statusBar->setProgressText(QString());
-        updateDirectoryLoadingProgress(-1);
+        m_statusBar->showProgress(QString(), -1);
+    }
+
+    if (m_urlNavigatorConnected) {
+        m_urlNavigatorConnected->setReadOnlyBadgeVisible(false);
     }
 }
 
 void DolphinViewContainer::slotDirectoryLoadingCompleted()
 {
-    if (!m_statusBar->progressText().isEmpty()) {
-        m_statusBar->setProgressText(QString());
-        m_statusBar->setProgress(100);
-    }
+    m_statusBar->showProgress(QString(), 100);
 
     if (isSearchUrl(url()) && m_view->itemsCount() == 0) {
         // The dir lister has been completed on a Baloo-URI and no items have been found. Instead
@@ -662,15 +644,26 @@ void DolphinViewContainer::slotDirectoryLoadingCompleted()
     } else {
         updateStatusBar();
     }
+
+    if (m_urlNavigatorConnected) {
+        m_urlNavigatorConnected->setReadOnlyBadgeVisible(rootItem().isLocalFile() && !rootItem().isWritable());
+    }
+
+    // Update admin bar visibility
+    if (m_view->url().scheme() == QStringLiteral("admin")) {
+        if (!m_adminBar) {
+            m_adminBar = new Admin::Bar(this);
+            m_topLayout->addWidget(m_adminBar, positionFor.adminBar, 0);
+        }
+        m_adminBar->setVisible(true, WithAnimation);
+    } else if (m_adminBar) {
+        m_adminBar->setVisible(false, WithAnimation);
+    }
 }
 
 void DolphinViewContainer::slotDirectoryLoadingCanceled()
 {
-    if (!m_statusBar->progressText().isEmpty()) {
-        m_statusBar->setProgressText(QString());
-        m_statusBar->setProgress(100);
-    }
-
+    m_statusBar->showProgress(QString(), 100);
     m_statusBar->setText(QString());
 }
 
@@ -820,18 +813,18 @@ void DolphinViewContainer::slotUrlNavigatorLocationChanged(const QUrl &url)
         if (url.scheme().startsWith(QLatin1String("http"))) {
             showMessage(i18nc("@info:status", // krazy:exclude=qmethods
                               "Dolphin does not support web pages, the web browser has been launched"),
-                        Information);
+                        KMessageWidget::Information);
         } else {
-            showMessage(i18nc("@info:status", "Protocol not supported by Dolphin, default application has been launched"), Information);
+            showMessage(i18nc("@info:status", "Protocol not supported by Dolphin, default application has been launched"), KMessageWidget::Information);
         }
 
         QDesktopServices::openUrl(url);
         redirect(QUrl(), m_urlNavigator->locationUrl(1));
     } else {
         if (!url.scheme().isEmpty()) {
-            showMessage(i18nc("@info:status", "Invalid protocol '%1'", url.scheme()), Error);
+            showMessage(i18nc("@info:status", "Invalid protocol '%1'", url.scheme()), KMessageWidget::Error);
         } else {
-            showMessage(i18nc("@info:status", "Invalid protocol"), Error);
+            showMessage(i18nc("@info:status", "Invalid protocol"), KMessageWidget::Error);
         }
         m_urlNavigator->goBack();
     }
@@ -839,7 +832,8 @@ void DolphinViewContainer::slotUrlNavigatorLocationChanged(const QUrl &url)
 
 void DolphinViewContainer::slotUrlSelectionRequested(const QUrl &url)
 {
-    m_view->markUrlsAsSelected({url});
+    // We do not want to select any item here because there is no reason to assume that the user wants to edit the folder we are emerging from. BUG: 424723
+
     m_view->markUrlAsCurrent(url); // makes the item scroll into view
 }
 
@@ -897,7 +891,7 @@ void DolphinViewContainer::closeSearchBox()
 void DolphinViewContainer::stopDirectoryLoading()
 {
     m_view->stopLoading();
-    m_statusBar->setProgress(100);
+    m_statusBar->showProgress(QString(), 100);
 }
 
 void DolphinViewContainer::slotStatusBarZoomLevelChanged(int zoomLevel)
@@ -905,9 +899,31 @@ void DolphinViewContainer::slotStatusBarZoomLevelChanged(int zoomLevel)
     m_view->setZoomLevel(zoomLevel);
 }
 
-void DolphinViewContainer::showErrorMessage(const QString &msg)
+void DolphinViewContainer::slotErrorMessageFromView(const QString &message, const int kioErrorCode)
 {
-    showMessage(msg, Error);
+    if (kioErrorCode == KIO::ERR_CANNOT_ENTER_DIRECTORY && m_view->url().scheme() == QStringLiteral("file")
+        && KProtocolInfo::isKnownProtocol(QStringLiteral("admin")) && !rootItem().isReadable()) {
+        // Explain to users that they need authentication to see the folder contents.
+        if (!m_authorizeToEnterFolderAction) { // This code is similar to parts of Admin::Bar::hideTheNextTimeAuthorizationExpires().
+            // We should not simply use the actAsAdminAction() itself here because that one always refers to the active view instead of this->m_view.
+            auto actAsAdminAction = Admin::WorkerIntegration::FriendAccess::actAsAdminAction();
+            m_authorizeToEnterFolderAction = new QAction{actAsAdminAction->icon(), actAsAdminAction->text(), this};
+            m_authorizeToEnterFolderAction->setToolTip(actAsAdminAction->toolTip());
+            m_authorizeToEnterFolderAction->setWhatsThis(actAsAdminAction->whatsThis());
+            connect(m_authorizeToEnterFolderAction, &QAction::triggered, this, [this, actAsAdminAction]() {
+                setActive(true);
+                actAsAdminAction->trigger();
+            });
+        }
+        showMessage(i18nc("@info", "Authorization required to enter this folder."), KMessageWidget::Error, {m_authorizeToEnterFolderAction});
+        return;
+    }
+    Q_EMIT showErrorMessage(message);
+}
+
+void DolphinViewContainer::showErrorMessage(const QString &message)
+{
+    showMessage(message, KMessageWidget::Error);
 }
 
 void DolphinViewContainer::slotPlacesModelChanged()
@@ -941,7 +957,7 @@ void DolphinViewContainer::slotCurrentDirectoryRemoved()
         setUrl(newUrl);
     }
 
-    showMessage(xi18n("Current location changed, <filename>%1</filename> is no longer accessible.", location), Warning);
+    showMessage(xi18n("Current location changed, <filename>%1</filename> is no longer accessible.", location), KMessageWidget::Warning);
 }
 
 void DolphinViewContainer::slotOpenUrlFinished(KJob *job)
