@@ -8,6 +8,7 @@
 
 #include "settings/viewmodes/viewsettingstab.h"
 
+#include <KCModule>
 #include <KLocalizedString>
 #include <KPluginFactory>
 
@@ -19,16 +20,16 @@
 
 K_PLUGIN_CLASS_WITH_JSON(DolphinViewModesConfigModule, "kcmdolphinviewmodes.json")
 
-DolphinViewModesConfigModule::DolphinViewModesConfigModule(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
+DolphinViewModesConfigModule::DolphinViewModesConfigModule(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
     , m_tabs()
 {
     setButtons(KCModule::Default | KCModule::Help | KCModule::Apply);
 
-    QVBoxLayout *topLayout = new QVBoxLayout(this);
+    QVBoxLayout *topLayout = new QVBoxLayout(widget());
     topLayout->setContentsMargins(0, 0, 0, 0);
 
-    QTabWidget *tabWidget = new QTabWidget(this);
+    QTabWidget *tabWidget = new QTabWidget(widget());
 
     // Initialize 'Icons' tab
     ViewSettingsTab *iconsTab = new ViewSettingsTab(ViewSettingsTab::IconsMode, tabWidget);
@@ -58,7 +59,7 @@ DolphinViewModesConfigModule::~DolphinViewModesConfigModule()
 
 void DolphinViewModesConfigModule::save()
 {
-    for (ViewSettingsTab *tab : qAsConst(m_tabs)) {
+    for (ViewSettingsTab *tab : std::as_const(m_tabs)) {
         tab->applySettings();
     }
     reparseConfiguration();
@@ -66,8 +67,8 @@ void DolphinViewModesConfigModule::save()
 
 void DolphinViewModesConfigModule::defaults()
 {
-    for (ViewSettingsTab *tab : qAsConst(m_tabs)) {
-        tab->restoreDefaultSettings();
+    for (ViewSettingsTab *tab : std::as_const(m_tabs)) {
+        tab->restoreDefaults();
     }
     reparseConfiguration();
 }
